@@ -1,6 +1,6 @@
 <?php
 /**
- * $Horde: kronolith/attendees.php,v 1.7.8.13 2007/01/11 18:17:46 jan Exp $
+ * $Horde: kronolith/attendees.php,v 1.7.8.14 2007/11/16 13:32:10 jan Exp $
  *
  * Copyright 2004-2007 Code Fusion  <http://www.codefusion.co.za/>
  *                Stuart Binge <s.binge@codefusion.co.za>
@@ -130,7 +130,7 @@ if (!$cal) {
     }
     $cal = array($cal);
 }
-$vfb = Kronolith::generateFreeBusy($cal, null, null, true);
+$vfb = Kronolith::generateFreeBusy($cal, null, null, true, Auth::getAuth());
 if (!is_a($vfb, 'PEAR_Error')) {
     $attendee_view->addRequiredMember($vfb);
 } else {
