@@ -3,7 +3,7 @@
  * "*" to options with class="selected" so that the user has an
  * indication of which shares are chosen.
  *
- * $Horde: kronolith/js/fixUnstyledOptions.js,v 1.1.2.1 2005/10/18 12:27:29 jan Exp $
+ * $Horde: kronolith/js/fixUnstyledOptions.js,v 1.1.2.2 2006/03/12 03:08:35 chuck Exp $
  */
 
 /* We do everything onload so that the entire document is present
@@ -29,7 +29,7 @@ function mark_selected_options()
         return;
     }
     options = document.getElementsByTagName('option');
-    for (i = 0; i < options.length; i++) {
+    for (var i = 0; i < options.length; ++i) {
         if (options[i].className.indexOf('selected') != -1) {
             options[i].innerHTML = "* " + options[i].innerHTML;
         }
