@@ -2,7 +2,7 @@
 /**
  * Kronolith external API interface.
  *
- * $Horde: kronolith/lib/api.php,v 1.126.2.23 2006/10/18 04:22:51 chuck Exp $
+ * $Horde: kronolith/lib/api.php,v 1.126.2.26.2.4 2008/01/09 21:56:32 chuck Exp $
  *
  * This file defines Kronolith's external API interface. Other applications
  * can interact with Kronolith through this API.
@@ -250,6 +250,10 @@ function _kronolith_list($calendar = null)
     if (empty($calendar)) {
         $calendar = Kronolith::getDefaultCalendar();
     }
+    if (!array_key_exists($calendar,
+                          Kronolith::listCalendars(false, PERMS_READ))) {
+        return PEAR::raiseError(_("Permission Denied"));
+    }
 
     $ids = Kronolith::listEventIds(0,
                                    new Horde_Date(array('year' => 9999, 'month' => 12, 'day' => 31)),
@@ -284,6 +288,11 @@ function _kronolith_listBy($action, $timestamp, $calendar = null)
         $calendar = Kronolith::getDefaultCalendar();
     }
 
+    if (!array_key_exists($calendar,
+                          Kronolith::listCalendars(false, PERMS_READ))) {
+        return PEAR::raiseError(_("Permission Denied"));
+    }
+
     $history = &Horde_History::singleton();
     $histories = $history->getByTimestamp('>', $timestamp, array(array('op' => '=', 'field' => 'action', 'value' => $action)), 'kronolith:' . $calendar);
     if (is_a($histories, 'PEAR_Error')) {
@@ -311,6 +320,11 @@ function _kronolith_getActionTimestamp($uid, $action, $calendar = null)
         $calendar = Kronolith::getDefaultCalendar();
     }
 
+    if (!array_key_exists($calendar,
+                          Kronolith::listCalendars(false, PERMS_READ))) {
+        return PEAR::raiseError(_("Permission Denied"));
+    }
+
     $history = &Horde_History::singleton();
     return $history->getActionTimestamp('kronolith:' . $calendar . ':' .
                                         $uid, $action);
@@ -493,7 +507,7 @@ function _kronolith_exportCalendar($calendar, $contentType)
 
         require_once 'Horde/iCalendar.php';
         $iCal = new Horde_iCalendar($version);
-        $iCal->setAttribute('X-WR-CALNAME', $share->get('name'));
+        $iCal->setAttribute('X-WR-CALNAME', String::convertCharset($share->get('name'), NLS::getCharset(), 'utf-8'));
 
         foreach ($events as $id) {
             $event = &$kronolith->getEvent($id);
@@ -543,21 +557,21 @@ function _kronolith_delete($uid)
     $ownerCalendars = Kronolith::listCalendars(true, PERMS_DELETE);
     $event = null;
     foreach ($events as $ev) {
-    	if (isset($ownerCalendars[$ev->getCalendar()])) {
+        if (isset($ownerCalendars[$ev->getCalendar()])) {
             $event = $ev;
             break;
-    	}
+        }
     }
 
     /* If not successful, try all calendars the user has access too. */
     if (empty($event)) {
-    	$deletableCalendars = Kronolith::listCalendars(false, PERMS_DELETE);
-    	foreach ($events as $ev) {
+        $deletableCalendars = Kronolith::listCalendars(false, PERMS_DELETE);
+        foreach ($events as $ev) {
             if (isset($deletableCalendars[$ev->getCalendar()])) {
                 $event = $ev;
                 break;
             }
-    	}
+        }
     }
 
     if (empty($event)) {
@@ -655,6 +669,8 @@ function _kronolith_getFreeBusy($startstamp = null, $endstamp = null,
     if (is_null($calendar)) {
         $calendar = Kronolith::getDefaultCalendar();
     }
+    // Free/Busy information is globally available; no permission
+    // check is needed.
 
     return Kronolith::generateFreeBusy($calendar, $startstamp, $endstamp, true);
 }
@@ -717,21 +733,21 @@ function _kronolith_updateAttendee($response)
     $ownerCalendars = Kronolith::listCalendars(true, PERMS_EDIT);
     $event = null;
     foreach ($events as $ev) {
-    	if (isset($ownerCalendars[$ev->getCalendar()])) {
+        if (isset($ownerCalendars[$ev->getCalendar()])) {
             $event = $ev;
             break;
-    	}
+        }
     }
 
     /* If not successful, try all calendars the user has access too. */
     if (empty($event)) {
-    	$editableCalendars = Kronolith::listCalendars(false, PERMS_EDIT);
-    	foreach ($events as $ev) {
+        $editableCalendars = Kronolith::listCalendars(false, PERMS_EDIT);
+        foreach ($events as $ev) {
             if (isset($editableCalendars[$ev->getCalendar()])) {
                 $event = $ev;
                 break;
             }
-    	}
+        }
     }
 
     if (empty($event)) {
@@ -739,15 +755,17 @@ function _kronolith_updateAttendee($response)
     }
 
     $atnames = $response->getAttribute('ATTENDEE');
-    $atparms = $response->getAttribute('ATTENDEE', true);
-
     if (!is_array($atnames)) {
         $atnames = array($atnames);
     }
+    $atparms = $response->getAttribute('ATTENDEE', true);
+
+    $found = false;
     foreach ($atnames as $index => $attendee) {
         $attendee = str_replace('mailto:', '', String::lower($attendee));
         if ($event->hasAttendee($attendee)) {
             $event->addAttendee($attendee, KRONOLITH_PART_IGNORE, Kronolith::responseFromICal($atparms[$index]['PARTSTAT']));
+            $found = true;
         }
     }
 
@@ -756,6 +774,10 @@ function _kronolith_updateAttendee($response)
         return $result;
     }
 
+    if (!$found) {
+        return PEAR::raiseError(_("No attendees have been updated because none of the provided email addresses have been found in the event's attendees list."));
+    }
+
     return true;
 }
 
@@ -780,6 +802,10 @@ function _kronolith_listEvents($startstamp = null, $endstamp = null,
     if (is_null($calendar)) {
         $calendar = $GLOBALS['prefs']->getValue('default_share');
     }
+    if (!array_key_exists($calendar,
+                          Kronolith::listCalendars(false, PERMS_EDIT))) {
+        return PEAR::raiseError(_("Permission Denied"));
+    }
 
     return Kronolith::listEvents($startstamp, $endstamp, $calendar, $showRecurrence);
 }
